#line 2 "align/stockl.c"

#line 4 "align/stockl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer stock_create_buffer
#define yy_delete_buffer stock_delete_buffer
#define yy_flex_debug stock_flex_debug
#define yy_init_buffer stock_init_buffer
#define yy_flush_buffer stock_flush_buffer
#define yy_load_buffer_state stock_load_buffer_state
#define yy_switch_to_buffer stock_switch_to_buffer
#define yyin stockin
#define yyleng stockleng
#define yylex stocklex
#define yylineno stocklineno
#define yyout stockout
#define yyrestart stockrestart
#define yytext stocktext
#define yywrap stockwrap
#define yyalloc stockalloc
#define yyrealloc stockrealloc
#define yyfree stockfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE stockrestart(stockin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int stockleng;

extern FILE *stockin, *stockout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up stocktext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up stocktext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via stockrestart()), so that the user can continue scanning by
	 * just pointing stockin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when stocktext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int stockleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow stockwrap()'s to do buffer switches
 * instead of setting up a fresh stockin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void stockrestart (FILE *input_file  );
void stock_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE stock_create_buffer (FILE *file,int size  );
void stock_delete_buffer (YY_BUFFER_STATE b  );
void stock_flush_buffer (YY_BUFFER_STATE b  );
void stockpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void stockpop_buffer_state (void );

static void stockensure_buffer_stack (void );
static void stock_load_buffer_state (void );
static void stock_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER stock_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE stock_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE stock_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE stock_scan_bytes (yyconst char *bytes,int len  );

void *stockalloc (yy_size_t  );
void *stockrealloc (void *,yy_size_t  );
void stockfree (void *  );

#define yy_new_buffer stock_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        stockensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            stock_create_buffer(stockin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        stockensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            stock_create_buffer(stockin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define stockwrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *stockin = (FILE *) 0, *stockout = (FILE *) 0;

typedef int yy_state_type;

extern int stocklineno;

int stocklineno = 1;

extern char *stocktext;
#define yytext_ptr stocktext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up stocktext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	stockleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 23
#define YY_END_OF_BUFFER 24
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[193] =
    {   0,
       24,   22,   23,   21,   23,   22,   23,16397,    5,   21,
       23,   22,   23,   22,   23,16397,   11,   23,   10,   23,
        7,   11,   23,    9,   11,   23,    8,   11,   23,    5,
       10,   23,   11,   23,   11,   23,   17,   23,   14,   17,
       23,   16,   23,   15,   17,   23,    5,   16,   23,   17,
       23,   17,   23,   20,   23,   19,   23,    5,   19,   23,
       20,   23,   20,   23,16397,   12,   18,16397,    8,   18,
       14,   15,16397, 8205,   12,   15,16397, 8205,   12,   15,
    16397, 8205,   12,    1,    2,    3,    4,   15,16397, 8205,
       12,   15,16397, 8205,   12,   15,16397, 8205,   12,   15,

    16397, 8205,   12,   15,16397, 8205,   12,   15,16397, 8205,
       12,    6,16397, 8205,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,16397,   12,16397,   12,16397,   12,16397,   12,16397,
       12,   12

    } ;

static yyconst flex_int16_t yy_accept[185] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    2,
        4,    6,    9,   12,   14,   17,   19,   21,   24,   27,
       30,   33,   35,   37,   39,   42,   44,   47,   50,   52,
       54,   56,   58,   61,   63,   65,   66,   66,   67,   67,
       67,   69,   70,   71,   72,   73,   74,   75,   76,   76,
       76,   77,   78,   79,   80,   80,   80,   80,   80,   80,
       81,   82,   83,   84,   84,   84,   85,   85,   86,   86,
       87,   87,   88,   89,   90,   91,   92,   92,   93,   94,
       95,   96,   96,   97,   98,   99,  100,  100,  101,  102,
      103,  104,  104,  105,  106,  107,  108,  108,  109,  110,

      111,  112,  113,  114,  115,  116,  117,  118,  119,  120,
      121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
      131,  132,  133,  134,  135,  136,  137,  138,  139,  140,
      141,  142,  143,  144,  145,  146,  147,  148,  149,  150,
      151,  152,  153,  154,  155,  156,  157,  158,  159,  160,
      161,  162,  163,  164,  165,  166,  167,  168,  169,  170,
      171,  172,  173,  174,  175,  176,  177,  178,  179,  180,
      181,  182,  183,  184,  185,  186,  187,  188,  189,  190,
      191,  192,  193,  193
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    5,    1,    1,    1,    1,    1,
        1,    6,    1,    1,    7,    8,    9,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,    1,    1,    1,
       11,    1,    1,    1,   12,   12,   13,   12,   12,   14,
       15,   16,   12,   12,   17,   18,   19,   12,   20,   12,
       12,   21,   22,   23,   12,   12,   12,   12,   12,   12,
        1,    1,    1,    1,   24,    1,   12,   12,   12,   12,

       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,    1,    1,    1,   25,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[26] =
    {   0,
        1,    2,    3,    2,    4,    5,    5,    5,    1,    1,
        1,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[310] =
    {   0,
      331,    0,    7,   15,   25,    3,  327,   48,  325,  713,
      713,   12,    0,   48,   52,  713,  713,  713,  713,  314,
      713,  309,  306,  713,   56,  713,    0,  713,  303,  301,
      713,  713,  713,  294,  295,   60,   61,    0,  278,  280,
       64,  284,  713,   65,    0,   68,    0,    0,  267,   60,
        0,   73,    0,    0,  265,  281,  277,  272,  271,    0,
       74,    0,    0,  257,  262,  713,  261,  713,  257,  713,
      232,  713,    0,   81,    0,    0,  217,    0,   82,    0,
        0,  214,    0,   85,    0,    0,  205,    0,   86,    0,
        0,  206,    0,   89,    0,    0,  201,  713,   90,    0,

        0,  713,   93,  713,    0,   94,    0,   97,    0,   98,
        0,  101,    0,  102,    0,  105,    0,  106,    0,  109,
        0,  110,    0,  113,    0,  114,    0,  117,    0,  118,
        0,  121,    0,  122,    0,  125,    0,  126,    0,  129,
        0,  130,    0,  133,    0,  134,    0,  137,    0,  138,
        0,  141,    0,  142,    0,  145,    0,  146,    0,  149,
        0,  150,    0,  153,    0,  154,    0,  157,    0,  158,
        0,  161,    0,  162,    0,  165,    0,  166,    0,  169,
        0,  713,  713,  173,  178,  183,  188,  193,  198,  210,
      203,  207,  212,  209,  217,  206,  222,  205,  227,  201,

      232,  237,  242,  247,  252,  197,  257,  196,  262,  195,
      267,  191,  272,  167,  277,   75,  282,   74,  287,   66,
      292,   50,  297,   17,  302,   16,  307,    8,  312,  317,
        2,  322,  327,  332,  337,  342,  347,  352,  357,  362,
      367,  372,  377,  382,  387,  392,  397,  402,  407,  412,
      417,  422,  427,  432,  437,  442,  447,  452,  457,  462,
      467,  472,  477,  482,  487,  492,  497,  502,  507,  512,
      517,  522,  527,  532,  537,  542,  547,  552,  557,  562,
      567,  572,  577,  582,  587,  592,  597,  602,  607,  612,
      617,  622,  627,  632,  637,  642,  647,  652,  657,  662,

      667,  672,  677,  682,  687,  692,  697,  702,  707
    } ;

static yyconst flex_int16_t yy_def[310] =
    {   0,
      184,  185,  186,  186,  183,    5,  187,  187,  183,  183,
      183,  188,  189,  183,  188,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  190,  183,  183,  183,
      183,  183,  183,  183,  183,  191,  192,  193,  183,  183,
      191,  183,  183,  183,  194,  195,  196,  197,  183,  183,
      198,  199,  200,  201,  183,  202,  203,  204,  205,  206,
      207,  208,  209,  183,  202,  183,  203,  183,  204,  183,
      205,  183,  210,  211,  212,  213,  183,  214,  215,  216,
      217,  183,  218,  219,  220,  221,  183,  222,  223,  224,
      225,  183,  226,  227,  228,  229,  183,  183,  230,  231,

      232,  183,  233,  183,  234,  235,  236,  237,  238,  239,
      240,  241,  242,  243,  244,  245,  246,  247,  248,  249,
      250,  251,  252,  253,  254,  255,  256,  257,  258,  259,
      260,  261,  262,  263,  264,  265,  266,  267,  268,  269,
      270,  271,  272,  273,  274,  275,  276,  277,  278,  279,
      280,  281,  282,  283,  284,  285,  286,  287,  288,  289,
      290,  291,  292,  293,  294,  295,  296,  297,  298,  299,
      300,  301,  302,  303,  304,  305,  306,  307,  308,  183,
      309,  183,    0,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,

      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,

      183,  183,  183,  183,  183,  183,  183,  183,  183
    } ;

static yyconst flex_int16_t yy_nxt[739] =
    {   0,
      183,   10,   13,   10,   14,   28,  104,   29,   15,   17,
       18,   30,  100,   37,   19,   37,   20,   21,   18,   22,
       98,   95,   19,   23,   20,   24,   25,   26,   25,   24,
       27,   27,   27,   24,   24,   24,   27,   27,   27,   27,
       27,   27,   27,   27,   27,   27,   27,   27,   27,   27,
       33,   39,   34,   37,   93,   37,   35,   44,   40,   44,
       41,   37,   37,   37,   37,   37,   44,   37,   44,   37,
       90,   37,   56,   57,   37,   37,   37,   37,   88,   85,
       58,   59,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,

       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   37,   37,   37,   37,   37,   37,   37,   37,   37,
       37,   83,   37,   10,   10,   10,   10,   10,   12,   12,
       12,   12,   12,   16,   16,   16,   16,   16,   31,   31,
       31,   31,   31,   36,   36,   80,   36,   36,   38,   78,

       75,   73,   38,   46,   46,   62,   46,   46,   47,   60,
       53,   47,   48,   51,   45,   48,   48,   52,   52,  102,
       52,   52,   54,   97,   92,   54,   54,   61,   61,   87,
       61,   61,   63,   82,   72,   63,   63,   65,   65,   65,
       65,   65,   67,   67,   67,   67,   67,   69,   69,   69,
       69,   69,   71,   71,   71,   71,   71,   74,   74,   70,
       74,   74,   76,   68,   66,   76,   76,   79,   79,   77,
       79,   79,   81,   72,   70,   81,   81,   84,   84,   68,
       84,   84,   86,   66,   64,   86,   86,   89,   89,   55,
       89,   89,   91,   42,   50,   91,   91,   94,   94,   49,

       94,   94,   96,   43,   40,   96,   96,   99,   99,   43,
       99,   99,  101,   40,   43,  101,  101,  103,  103,   40,
      103,  103,  105,   42,  183,  105,  105,  106,  106,   32,
      106,  106,  107,   11,  183,  107,  107,  108,  108,  183,
      108,  108,  109,  183,  183,  109,  109,  110,  110,  183,
      110,  110,  111,  183,  183,  111,  111,  112,  112,  183,
      112,  112,  113,  183,  183,  113,  113,  114,  114,  183,
      114,  114,  115,  183,  183,  115,  115,  116,  116,  183,
      116,  116,  117,  183,  183,  117,  117,  118,  118,  183,
      118,  118,  119,  183,  183,  119,  119,  120,  120,  183,

      120,  120,  121,  183,  183,  121,  121,  122,  122,  183,
      122,  122,  123,  183,  183,  123,  123,  124,  124,  183,
      124,  124,  125,  183,  183,  125,  125,  126,  126,  183,
      126,  126,  127,  183,  183,  127,  127,  128,  128,  183,
      128,  128,  129,  183,  183,  129,  129,  130,  130,  183,
      130,  130,  131,  183,  183,  131,  131,  132,  132,  183,
      132,  132,  133,  183,  183,  133,  133,  134,  134,  183,
      134,  134,  135,  183,  183,  135,  135,  136,  136,  183,
      136,  136,  137,  183,  183,  137,  137,  138,  138,  183,
      138,  138,  139,  183,  183,  139,  139,  140,  140,  183,

      140,  140,  141,  183,  183,  141,  141,  142,  142,  183,
      142,  142,  143,  183,  183,  143,  143,  144,  144,  183,
      144,  144,  145,  183,  183,  145,  145,  146,  146,  183,
      146,  146,  147,  183,  183,  147,  147,  148,  148,  183,
      148,  148,  149,  183,  183,  149,  149,  150,  150,  183,
      150,  150,  151,  183,  183,  151,  151,  152,  152,  183,
      152,  152,  153,  183,  183,  153,  153,  154,  154,  183,
      154,  154,  155,  183,  183,  155,  155,  156,  156,  183,
      156,  156,  157,  183,  183,  157,  157,  158,  158,  183,
      158,  158,  159,  183,  183,  159,  159,  160,  160,  183,

      160,  160,  161,  183,  183,  161,  161,  162,  162,  183,
      162,  162,  163,  183,  183,  163,  163,  164,  164,  183,
      164,  164,  165,  183,  183,  165,  165,  166,  166,  183,
      166,  166,  167,  183,  183,  167,  167,  168,  168,  183,
      168,  168,  169,  183,  183,  169,  169,  170,  170,  183,
      170,  170,  171,  183,  183,  171,  171,  172,  172,  183,
      172,  172,  173,  183,  183,  173,  173,  174,  174,  183,
      174,  174,  175,  183,  183,  175,  175,  176,  176,  183,
      176,  176,  177,  183,  183,  177,  177,  178,  178,  183,
      178,  178,  179,  183,  183,  179,  179,  180,  180,  183,

      180,  180,  181,  183,  183,  181,  181,  182,  183,  183,
      182,  182,    9,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183
    } ;

static yyconst flex_int16_t yy_chk[739] =
    {   0,
        0,    2,    2,    2,    2,    6,  231,    6,    2,    3,
        3,    6,  228,   12,    3,   12,    3,    4,    4,    4,
      226,  224,    4,    4,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        8,   14,    8,   15,  222,   15,    8,   25,   14,   25,
       15,   36,   37,   36,   37,   41,   44,   41,   44,   46,
      220,   46,   50,   50,   52,   61,   52,   61,  218,  216,
       50,   50,   74,   79,   74,   79,   84,   89,   84,   89,
       94,   99,   94,   99,  103,  106,  103,  106,  108,  110,

      108,  110,  112,  114,  112,  114,  116,  118,  116,  118,
      120,  122,  120,  122,  124,  126,  124,  126,  128,  130,
      128,  130,  132,  134,  132,  134,  136,  138,  136,  138,
      140,  142,  140,  142,  144,  146,  144,  146,  148,  150,
      148,  150,  152,  154,  152,  154,  156,  158,  156,  158,
      160,  162,  160,  162,  164,  166,  164,  166,  168,  170,
      168,  170,  172,  174,  172,  174,  176,  178,  176,  178,
      180,  214,  180,  184,  184,  184,  184,  184,  185,  185,
      185,  185,  185,  186,  186,  186,  186,  186,  187,  187,
      187,  187,  187,  188,  188,  212,  188,  188,  189,  210,

      208,  206,  189,  191,  191,  200,  191,  191,  192,  198,
      196,  192,  193,  194,  190,  193,  193,  195,  195,   97,
      195,  195,  197,   92,   87,  197,  197,  199,  199,   82,
      199,  199,  201,   77,   71,  201,  201,  202,  202,  202,
      202,  202,  203,  203,  203,  203,  203,  204,  204,  204,
      204,  204,  205,  205,  205,  205,  205,  207,  207,   69,
      207,  207,  209,   67,   65,  209,  209,  211,  211,   64,
      211,  211,  213,   59,   58,  213,  213,  215,  215,   57,
      215,  215,  217,   56,   55,  217,  217,  219,  219,   49,
      219,  219,  221,   42,   40,  221,  221,  223,  223,   39,

      223,  223,  225,   35,   34,  225,  225,  227,  227,   30,
      227,  227,  229,   29,   23,  229,  229,  230,  230,   22,
      230,  230,  232,   20,    9,  232,  232,  233,  233,    7,
      233,  233,  234,    1,    0,  234,  234,  235,  235,    0,
      235,  235,  236,    0,    0,  236,  236,  237,  237,    0,
      237,  237,  238,    0,    0,  238,  238,  239,  239,    0,
      239,  239,  240,    0,    0,  240,  240,  241,  241,    0,
      241,  241,  242,    0,    0,  242,  242,  243,  243,    0,
      243,  243,  244,    0,    0,  244,  244,  245,  245,    0,
      245,  245,  246,    0,    0,  246,  246,  247,  247,    0,

      247,  247,  248,    0,    0,  248,  248,  249,  249,    0,
      249,  249,  250,    0,    0,  250,  250,  251,  251,    0,
      251,  251,  252,    0,    0,  252,  252,  253,  253,    0,
      253,  253,  254,    0,    0,  254,  254,  255,  255,    0,
      255,  255,  256,    0,    0,  256,  256,  257,  257,    0,
      257,  257,  258,    0,    0,  258,  258,  259,  259,    0,
      259,  259,  260,    0,    0,  260,  260,  261,  261,    0,
      261,  261,  262,    0,    0,  262,  262,  263,  263,    0,
      263,  263,  264,    0,    0,  264,  264,  265,  265,    0,
      265,  265,  266,    0,    0,  266,  266,  267,  267,    0,

      267,  267,  268,    0,    0,  268,  268,  269,  269,    0,
      269,  269,  270,    0,    0,  270,  270,  271,  271,    0,
      271,  271,  272,    0,    0,  272,  272,  273,  273,    0,
      273,  273,  274,    0,    0,  274,  274,  275,  275,    0,
      275,  275,  276,    0,    0,  276,  276,  277,  277,    0,
      277,  277,  278,    0,    0,  278,  278,  279,  279,    0,
      279,  279,  280,    0,    0,  280,  280,  281,  281,    0,
      281,  281,  282,    0,    0,  282,  282,  283,  283,    0,
      283,  283,  284,    0,    0,  284,  284,  285,  285,    0,
      285,  285,  286,    0,    0,  286,  286,  287,  287,    0,

      287,  287,  288,    0,    0,  288,  288,  289,  289,    0,
      289,  289,  290,    0,    0,  290,  290,  291,  291,    0,
      291,  291,  292,    0,    0,  292,  292,  293,  293,    0,
      293,  293,  294,    0,    0,  294,  294,  295,  295,    0,
      295,  295,  296,    0,    0,  296,  296,  297,  297,    0,
      297,  297,  298,    0,    0,  298,  298,  299,  299,    0,
      299,  299,  300,    0,    0,  300,  300,  301,  301,    0,
      301,  301,  302,    0,    0,  302,  302,  303,  303,    0,
      303,  303,  304,    0,    0,  304,  304,  305,  305,    0,
      305,  305,  306,    0,    0,  306,  306,  307,  307,    0,

      307,  307,  308,    0,    0,  308,  308,  309,    0,    0,
      309,  309,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183
    } ;

extern int stock_flex_debug;
int stock_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up stocktext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *stocktext;
#line 1 "align/stockl.l"
/* stockl.l - STOCKHOLM alignment lexer */
#line 4 "align/stockl.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif

#include "align/stocky.h"
#define YY_NO_INPUT 1

#line 779 "align/stockl.c"

#define INITIAL 0
#define HDRTAG 1
#define SEQTAG 2
#define ENDTAG 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int stocklex_destroy (void );

int stockget_debug (void );

void stockset_debug (int debug_flag  );

YY_EXTRA_TYPE stockget_extra (void );

void stockset_extra (YY_EXTRA_TYPE user_defined  );

FILE *stockget_in (void );

void stockset_in  (FILE * _in_str  );

FILE *stockget_out (void );

void stockset_out  (FILE * _out_str  );

int stockget_leng (void );

char *stockget_text (void );

int stockget_lineno (void );

void stockset_lineno (int _line_number  );

YYSTYPE * stockget_lval (void );

void stockset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int stockwrap (void );
#else
extern int stockwrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( stocktext, stockleng, 1, stockout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( stockin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( stockin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, stockin))==0 && ferror(stockin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(stockin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int stocklex \
               (YYSTYPE * yylval_param );

#define YY_DECL int stocklex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after stocktext and stockleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( stockleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(stocktext[stockleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 40 "align/stockl.l"


#line 980 "align/stockl.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)stockalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in stocklex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! stockin )
			stockin = stdin;

		if ( ! stockout )
			stockout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			stockensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				stock_create_buffer(stockin,YY_BUF_SIZE );
		}

		stock_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of stocktext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 184 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 183 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 42 "align/stockl.l"
/* Column annot. markup ignored */
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 43 "align/stockl.l"
/* File annot. markup ignored */
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 44 "align/stockl.l"
/* Residue annot. markup ignored */
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 45 "align/stockl.l"
/* Sequence annot. markup ignored */
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 46 "align/stockl.l"
/* Empty lines ignored */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 48 "align/stockl.l"
{ BEGIN HDRTAG; return TAG; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 49 "align/stockl.l"
{ return SPC; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 50 "align/stockl.l"
{ return INT; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 51 "align/stockl.l"
{ return DOT; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 52 "align/stockl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 53 "align/stockl.l"
{ return ERR; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up stocktext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up stocktext again */
YY_RULE_SETUP
#line 55 "align/stockl.l"
{ return EOL; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 56 "align/stockl.l"
{ BEGIN SEQTAG; yylval->str = strdup(stocktext); return NAM; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 57 "align/stockl.l"
{ return SPC; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 58 "align/stockl.l"
{ yylval->str = strdup(stocktext); return BAS; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 59 "align/stockl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 60 "align/stockl.l"
{ return ERR; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "align/stockl.l"
{ BEGIN ENDTAG; return END; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 63 "align/stockl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case YY_STATE_EOF(ENDTAG):
#line 64 "align/stockl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 65 "align/stockl.l"
{ return ERR; }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 67 "align/stockl.l"
{ return ERR; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 68 "align/stockl.l"
{ return ERR; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 70 "align/stockl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1227 "align/stockl.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(HDRTAG):
			case YY_STATE_EOF(SEQTAG):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed stockin at a new source and called
			 * stocklex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = stockin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( stockwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * stocktext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of stocklex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			stockrestart(stockin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) stockrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 184 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 184 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 183);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					stockrestart(stockin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( stockwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve stocktext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void stockrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        stockensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            stock_create_buffer(stockin,YY_BUF_SIZE );
	}

	stock_init_buffer(YY_CURRENT_BUFFER,input_file );
	stock_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void stock_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		stockpop_buffer_state();
	 *		stockpush_buffer_state(new_buffer);
     */
	stockensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	stock_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (stockwrap()) processing, but the only time this flag
	 * is looked at is after stockwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void stock_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	stockin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE stock_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) stockalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in stock_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) stockalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in stock_create_buffer()" );

	b->yy_is_our_buffer = 1;

	stock_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with stock_create_buffer()
 * 
 */
    void stock_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		stockfree((void *) b->yy_ch_buf  );

	stockfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a stockrestart() or at EOF.
 */
    static void stock_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	stock_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then stock_init_buffer was _probably_
     * called from stockrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void stock_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		stock_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void stockpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	stockensure_buffer_stack();

	/* This block is copied from stock_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from stock_switch_to_buffer. */
	stock_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void stockpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	stock_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		stock_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void stockensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)stockalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in stockensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)stockrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in stockensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE stock_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) stockalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in stock_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	stock_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to stocklex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       stock_scan_bytes() instead.
 */
YY_BUFFER_STATE stock_scan_string (yyconst char * yystr )
{
    
	return stock_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to stocklex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE stock_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) stockalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in stock_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = stock_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in stock_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up stocktext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		stocktext[stockleng] = (yy_hold_char); \
		(yy_c_buf_p) = stocktext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		stockleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int stockget_lineno  (void)
{
        
    return stocklineno;
}

/** Get the input stream.
 * 
 */
FILE *stockget_in  (void)
{
        return stockin;
}

/** Get the output stream.
 * 
 */
FILE *stockget_out  (void)
{
        return stockout;
}

/** Get the length of the current token.
 * 
 */
int stockget_leng  (void)
{
        return stockleng;
}

/** Get the current token.
 * 
 */

char *stockget_text  (void)
{
        return stocktext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void stockset_lineno (int  _line_number )
{
    
    stocklineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see stock_switch_to_buffer
 */
void stockset_in (FILE *  _in_str )
{
        stockin = _in_str ;
}

void stockset_out (FILE *  _out_str )
{
        stockout = _out_str ;
}

int stockget_debug  (void)
{
        return stock_flex_debug;
}

void stockset_debug (int  _bdebug )
{
        stock_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from stocklex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    stockin = stdin;
    stockout = stdout;
#else
    stockin = (FILE *) 0;
    stockout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * stocklex_init()
     */
    return 0;
}

/* stocklex_destroy is for both reentrant and non-reentrant scanners. */
int stocklex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		stock_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		stockpop_buffer_state();
	}

	/* Destroy the stack itself. */
	stockfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    stockfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * stocklex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *stockalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *stockrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void stockfree (void * ptr )
{
	free( (char *) ptr );	/* see stockrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 70 "align/stockl.l"



